@@ -343,10 +343,10 @@ class Media(TimeStampedModelMixin, models.Model):
                 except Exception:
                     # We have an original file but something's wrong with it.
                     # Might be 0 bytes or something.
-                    return static("img/original_error.jpg")
+                    return static("ditto-core/img/original_error.jpg")
         else:
             # We haven't downloaded an original file for this.
-            return static("img/original_missing.jpg")
+            return static("ditto-core/img/original_missing.jpg")
 
     def _remote_image_url(self, size):
         """
@@ -711,9 +711,8 @@ class User(TimeStampedModelMixin, DiffModelMixin, models.Model):
         blank=False,
         default=0,
         help_text=(
-            "The number of tweets this user has favorited in "
-            "the account’s lifetime"
-        )
+            "The number of tweets this user has favorited in " "the account’s lifetime"
+        ),
     )
     followers_count = models.PositiveIntegerField(
         null=False,
